==> gorilla-notebook-0.4.11.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.output.html.js <==
goog.provide('pinkgorilla.output.html');
goog.require('cljs.core');
goog.require('reagent.core');
goog.require('pinkgorilla.output.hack');
/**
 * Setting innerHTML (dangerouslySetInnerHTML) or textContent does not
 *  execute scripts! Thats why we clone and replace the elements.
 */
pinkgorilla.output.html.process_scripts_BANG_ = (function pinkgorilla$output$html$process_scripts_BANG_(el){
var scripts = Array.from(el.getElementsByTagName("SCRIPT"));
return cljs.core.doall.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$2((function (script){
var newScript = (function (){var G__55480 = document.createElement("script");
(G__55480["textContent"] = script.textContent);

return G__55480;
})();
var temp__5733__auto___55481 = script.getAttribute("src");
if(cljs.core.truth_(temp__5733__auto___55481)){
var src_55482 = temp__5733__auto___55481;
newScript.setAttribute("src",src_55482);
} else {
}

return script.replaceWith(newScript);
}),scripts));
});
pinkgorilla.output.html.output_html = (function pinkgorilla$output$html$output_html(output,_){
var temp__5733__auto__ = new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output);
if(cljs.core.truth_(temp__5733__auto__)){
var content = temp__5733__auto__;
if(typeof content === 'string'){
return reagent.core.create_class(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"display-name","display-name",694513143),"output-html",new cljs.core.Keyword(null,"component-did-mount","component-did-mount",-1126910518),(function (this$){
return pinkgorilla.output.html.process_scripts_BANG_(reagent.core.dom_node(this$));
}),new cljs.core.Keyword(null,"reagent-render","reagent-render",-985383853),(function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"dangerouslySetInnerHTML","dangerouslySetInnerHTML",-554971138),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"__html","__html",674048345),content], null)], null)], null);
})], null));
} else {
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"span.value","span.value",1986660361),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"data-value","data-value",-1897915206),new cljs.core.Keyword(null,"value","value",305978217).cljs$core$IFn$_invoke$arity$1(output)], null),pinkgorilla.output.hack.temp_comp_hack(new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output))], null);

}
} else {
return null;
}
});

//# sourceMappingURL=pinkgorilla.output.html.js.map

==> gorilla-notebook-0.4.12.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.output.html.js <==
goog.provide('pinkgorilla.output.html');
goog.require('cljs.core');
goog.require('reagent.core');
goog.require('reagent.dom');
goog.require('pinkgorilla.output.hack');
/**
 * Setting innerHTML (dangerouslySetInnerHTML) or textContent does not
 *  execute scripts! Thats why we clone and replace the elements.
 */
pinkgorilla.output.html.process_scripts_BANG_ = (function pinkgorilla$output$html$process_scripts_BANG_(el){
var scripts = Array.from(el.getElementsByTagName("SCRIPT"));
return cljs.core.doall.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$2((function (script){
var newScript = (function (){var G__48706 = document.createElement("script");
(G__48706["textContent"] = script.textContent);

return G__48706;
})();
var temp__5733__auto___48708 = script.getAttribute("src");
if(cljs.core.truth_(temp__5733__auto___48708)){
var src_48709 = temp__5733__auto___48708;
newScript.setAttribute("src",src_48709);
} else {
}

return script.replaceWith(newScript);
}),scripts));
});
pinkgorilla.output.html.output_html = (function pinkgorilla$output$html$output_html(output,_){
var temp__5733__auto__ = new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output);
if(cljs.core.truth_(temp__5733__auto__)){
var content = temp__5733__auto__;
if(typeof content === 'string'){
return reagent.core.create_class(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"display-name","display-name",694513143),"output-html",new cljs.core.Keyword(null,"component-did-mount","component-did-mount",-1126910518),(function (this$){
return pinkgorilla.output.html.process_scripts_BANG_(reagent.dom.dom_node(this$));
}),new cljs.core.Keyword(null,"reagent-render","reagent-render",-985383853),(function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"dangerouslySetInnerHTML","dangerouslySetInnerHTML",-554971138),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"__html","__html",674048345),content], null)], null)], null);
})], null));
} else {
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"span.value","span.value",1986660361),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"data-value","data-value",-1897915206),new cljs.core.Keyword(null,"value","value",305978217).cljs$core$IFn$_invoke$arity$1(output)], null),pinkgorilla.output.hack.temp_comp_hack(new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output))], null);

}
} else {
return null;
}
});

//# sourceMappingURL=pinkgorilla.output.html.js.map
